@@ -66,15 +66,15 @@
 
 /* definition de tous les type de bus */
 Tsearchdrive listesearchdrives[] = {
-    { "", "", "SCSI", 100 }, /* scsi (sg) */
-#ifdef LINUX_IDE  /* pure ide devices with linux */
-    { "dev=/dev/hda", "/dev/hda", "IDE", 40 },
-    { "dev=/dev/hdb", "/dev/hdb", "IDE", 40 },
-    { "dev=/dev/hdc", "/dev/hdc", "IDE", 40},
-    { "dev=/dev/hdd", "/dev/hdd", "IDE", 40 },
+#if LINUX_IDE /* pure ide devices with linux */
+    { "dev=/dev/hda", "/dev/hda", "IDE", 100 },
+    { "dev=/dev/hdb", "/dev/hdb", "IDE", 100 },
+    { "dev=/dev/hdc", "/dev/hdc", "IDE", 100 },
+    { "dev=/dev/hdd", "/dev/hdd", "IDE", 100 },
 #endif
-    { "dev=ATA:", "ATA:", "ATA", 80 }, /* ide sg */
-    { "dev=ATAPI:", "ATAPI:", "ATAPI", 60 }, /* ide */
+    { "", "", "SCSI", 80 }, /* scsi (sg) */
+    { "dev=ATA:", "ATA:", "ATA", 60 }, /* ide sg */
+    { "dev=ATAPI:", "ATAPI:", "ATAPI", 40 }, /* ide */
     { NULL, NULL, NULL, 0}
   };
 
@@ -153,19 +153,12 @@ gboolean scan_callback(GIOChannel *Astd, GIOCondition Acond, gpointer Adata)
   if (!Lbuffer) return FALSE;
     
   g_strstrip(Lbuffer);  
-/* _DEB("scan lecteur = %s\n", Lbuffer); */
+_DEB("scan lecteur = %s\n", Lbuffer);
   if (extractlecteur(Lbuffer, &Ldev, &Lmarque, &Lmodel, &Lquoi) == TRUE) {
 
     insert_or_update_drive(Ldev, Lmarque, Lmodel, Lquoi, Ldrivedesc);
 
     _DEB("oui un lecteur");
-/*    
-    g_snprintf(Gldrives[Gnumdrives].dev, sizeof(Gldrives[Gnumdrives].dev)-1, "%s%s", Lbustype, Ldev);
-    g_snprintf(Gldrives[Gnumdrives].name, sizeof(Gldrives[Gnumdrives].name)-1,
-      "%s %s %s", Lmarque, Lmodel, Lquoi);
-    Gldrives[Gnumdrives].type = -1;
-    Gldrives[Gnumdrives].vitesse = 0;
-    Gnumdrives++;*/
     
     g_free(Lquoi);
     g_free(Lmodel);
@@ -244,6 +237,8 @@ gboolean maj_drive_info(Tdriveinfo *Adrive, gchar *Adev, GError **Aerror)
   gint Ltype = 0;
 
   Lcommandline = g_strdup_printf("%s -prcap dev=%s", conf_get_string("cdrecord"), Adev);
+  printf("==================%s\n", Lcommandline);  
+
 _DEB("==================%s\n", Lcommandline);  
   Lstatus = g_spawn_command_line_sync(Lcommandline, &Lout, &Lerr, &Lexit, Aerror);
   g_free(Lcommandline);
@@ -443,7 +438,7 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
     while (*Lcont > 0 && *Labort == FALSE) {
       gtk_main_iteration();    
     }
-    exit_prog(*Lpid, Aerror, NULL);
+    exit_prog(*Lpid, *Labort, Aerror, NULL);
 
     g_source_remove(Lcomevent);
     g_source_remove(Lcomerrevent);
@@ -822,7 +817,7 @@ _DEB("execution [%s]\n", Lcommandline);
     while (*Lcont>0 && *Labort == FALSE) {
       gtk_main_iteration(); 
     }
-    exit_prog(*Lpid, Aerror, NULL);
+    exit_prog(*Lpid, *Labort, Aerror, NULL);
 
     g_source_remove(Lcomerrevent);
     g_source_remove(Lcomevent);
@@ -981,7 +976,7 @@ _DEB("cont vaut => %d\n", *Lcont);
 _DEB("fin !!!\n");
   while (*Lcont > 0) { while(gtk_events_pending()) gtk_main_iteration(); }
 
-  exit_prog(*Lpid, Aerror, NULL);
+  exit_prog(*Lpid, FALSE, Aerror, NULL);
 
   g_source_remove(Lcomerrevent);
   g_source_remove(Lcomevent);
@@ -1050,7 +1045,7 @@ _DEB("cont vaut => %d\n", *Lcont);
 _DEB("fin !!!\n");
   while (*Lcont > 0) { while(gtk_events_pending()) gtk_main_iteration(); }
 
-  exit_prog(*Lpid, Aerror, NULL);
+  exit_prog(*Lpid, FALSE, Aerror, NULL);
 
   g_source_remove(Lcomerrevent);
   g_source_remove(Lcomevent);
