@@ -1,5 +1,5 @@
 /* config.c
- * Copyright (C) 2004, 2005 Sylvain Cresto <sylvain.cresto@tiscali.fr>
+ * Copyright (C) 2004, 2005 Sylvain Cresto <scresto@gmail.com>
  *
  * This file is part of graveman!
  *
@@ -42,14 +42,18 @@ TProgRequis Glisteprogrequis[] = {
   { CONF_STRING, "soxpara", "", CONF_SAVEALWAYS },
   { CONF_PROG, "dvd+rw-mediainfo", "", CONF_SAVEALWAYS },
   { CONF_STRING, "dvd+rw-mediainfopara", "", CONF_SAVEALWAYS },
+  { CONF_PROG, "dvd+rw-format", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "dvd+rw-formatpara", "", CONF_SAVEALWAYS },
   { CONF_PROG, "growisofs", "", CONF_SAVEALWAYS },
   { CONF_STRING, "growisofspara", "", CONF_SAVEALWAYS },
+  { CONF_PROG, "cdrdao", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "cdrdaopara", "", CONF_SAVEALWAYS },
   { CONF_DIR, "tmpdir", "/tmp", CONF_SAVEALWAYS },
   { CONF_STRING, "overburn", "1", CONF_SAVEALWAYS },
   { CONF_STRING, "autoblank", "1", CONF_SAVEALWAYS },
   { CONF_STRING, "fastblank", "1", CONF_SAVEALWAYS },
   { CONF_STRING, "eject", "1", CONF_SAVEALWAYS },
-  { CONF_STRING, "iconsize", "48", CONF_SAVEALWAYS },
+  { CONF_STRING, "iconsize", "24", CONF_SAVEALWAYS },
   { CONF_STRING, "statusbar", "1", CONF_SAVEALWAYS },
   { CONF_STRING, "saveconfig", "1", CONF_SAVEALWAYS },
 
@@ -57,8 +61,8 @@ TProgRequis Glisteprogrequis[] = {
   { CONF_STRING, "dstaudiocombo", "", CONF_SAVEONEXIT + CONF_COMBO },
   { CONF_STRING, "dstaudiospeed", "", CONF_SAVEONEXIT + CONF_COMBO },
   { CONF_STRING, "audiodao", "1", CONF_SAVEONEXIT + CONF_CHECK },
-  { CONF_STRING, "audionotfix", "1", CONF_SAVEONEXIT + CONF_CHECK },
-  { CONF_STRING, "audiosimul", "1", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "audionotfix", "", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "audiosimul", "", CONF_SAVEONEXIT + CONF_CHECK },
   { CONF_STRING, "nbrcdaudio", "1", CONF_SAVEONEXIT + CONF_SPIN },
   
   /* onglet data */
@@ -74,12 +78,20 @@ TProgRequis Glisteprogrequis[] = {
   { CONF_STRING, "datanotfix", "", CONF_SAVEONEXIT + CONF_CHECK },
   { CONF_STRING, "datasimul", "", CONF_SAVEONEXIT + CONF_CHECK },
 
+  /* onglet dvd data */
+  { CONF_STRING, "dstdvddatacombo", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "dstdvddataspeed", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "nbrdvddata", "1", CONF_SAVEONEXIT + CONF_SPIN },
+  { CONF_STRING, "dvddatanotfix", "", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "dvddatasimul", "", CONF_SAVEONEXIT + CONF_CHECK },
+
+
  /* onglet copier */
   { CONF_STRING, "srccopycombo", "", CONF_SAVEONEXIT + CONF_COMBO },
   { CONF_STRING, "dstcopycombo", "", CONF_SAVEONEXIT + CONF_COMBO },
   { CONF_STRING, "dstcopyspeed", "", CONF_SAVEONEXIT + CONF_COMBO },
   { CONF_STRING, "nbrcdcopy", "1", CONF_SAVEONEXIT + CONF_SPIN },
-  { CONF_STRING, "copysimul", "1", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "copysimul", "", CONF_SAVEONEXIT + CONF_CHECK },
 
   /* onglet autres */
   { CONF_STRING, "dstothercombo", "", CONF_SAVEONEXIT + CONF_COMBO },
@@ -87,6 +99,7 @@ TProgRequis Glisteprogrequis[] = {
 #if 0
   { CONF_STRING, "extended", FALSE, "1" },
 #endif
+  { CONF_STRING, "version", "1", CONF_SAVEALWAYS },
   { CONF_IGNORE, NULL, NULL, 0 },
 };
 
@@ -100,23 +113,6 @@ TProgRequis *getentrydef(gchar *Aentry)
   return NULL;
 }
 
-/* recuperation du nom de fichier ou ecrire */
-gchar *get_config_file_name()
-{
-  const gchar *LHome = g_getenv("HOME");
-  gchar *Ldir = g_strdup_printf("%s/.%s", LHome, PACKAGE);
-  gchar *Lfile = g_strdup_printf("%s/.%s/%s.conf", LHome, PACKAGE, PACKAGE);
-
-  /* tentative de creation du repertoire si il n'existe pas deja */
-  if (g_file_test(Ldir, G_FILE_TEST_EXISTS) == FALSE) {
-    mkdir(Ldir, 00750);
-  }
-  g_free(Ldir);
-
-  return (Lfile);
-}
-
-
 /* callback ecriture fichier de conf */
 void foreachconfig(gpointer Akey, gpointer Avalue, gpointer Adata)
 {
@@ -152,17 +148,19 @@ void foreachdrives(gpointer Adrive, gpointer Adata)
   fprintf(Lfic, "name=%s\n", Ldrive->name);  
   fprintf(Lfic, "type=%d\n", Ldrive->type);
   fprintf(Lfic, "vitesse=%d\n", Ldrive->vitesse);
+  fprintf(Lfic, "vitessedvd=%d\n", Ldrive->vitessedvd);
   fprintf(Lfic, "manual=%d\n", Ldrive->manual == TRUE ? 1 : 0);
 }
 
 /* ecriture du fichier de configuration */
-gint write_conf(gchar *AFichier, GError **Aerror)
+gboolean write_conf(GError **Aerror)
 {
   FILE *Lfic;
   gchar *Ltmp;
+  if (!get_config_file(W_OK)) return FALSE;
 
-  if (!(Lfic=fopen(AFichier, "w"))) {
-    Ltmp = g_strdup_printf(_("Cannot create %s: %s"), AFichier, g_strerror(errno));
+  if (!(Lfic=fopen(Gfileconf, "w"))) {
+    Ltmp = g_strdup_printf(_("Cannot create %s: %s"), Gfileconf, g_strerror(errno));
     g_set_error(Aerror, G_FILE_ERROR, g_file_error_from_errno(errno), Ltmp, g_strerror(errno)); 
     g_warning("%s", Ltmp);
     g_free(Ltmp);
@@ -171,6 +169,7 @@ gint write_conf(gchar *AFichier, GError **Aerror)
   }
 
   fprintf(Lfic, "[general]\n");
+  fprintf(Lfic, "confversion=%s\n", VERSION);
   g_hash_table_foreach(Gconfigprog, foreachconfig, (gpointer *)(Lfic));
 
 /*  g_slist_foreach(Gmedialist, foreachmedia, (gpointer *)(fic)); */
@@ -181,7 +180,7 @@ gint write_conf(gchar *AFichier, GError **Aerror)
 
   fclose(Lfic);
 
-  return EXIT_SUCCESS;
+  return TRUE;
 }
 
 /* initialisation de la configuration et des valeurs par default */
@@ -194,7 +193,7 @@ void config_init()
   conf_store_value("fastblank", "1");
   conf_store_value("tmpdir", "/tmp");
   conf_store_value("lastdir", "");
-  conf_store_value("iconsize", "48");
+  conf_store_value("iconsize", "24");
   conf_store_value("statusbar", "1");
   conf_store_value("saveconfig", "1");
   if (s) {
@@ -205,21 +204,66 @@ void config_init()
 
 /* on regarde si un fichier de configuration existe 
  * dans /usr/share/graveman/graveman.rc ou ~/.graveman/graveman.rc */
-gint is_config_valide()
+
+/* construction de la liste des PATH dans lequel on va chercher la configuration */
+GSList *get_config_path()
 {
-  const gchar *LHome = g_getenv("HOME");
-  gchar LUserConf[1024], LGlobalConf[1024];
+  GSList *Lnewlist = NULL;
+  const gchar *Lenv;
+  gchar *Lpath;
+  gchar **Llistpath;
+  gint i;
 
-  bzero(&LUserConf, sizeof(LUserConf));
-  bzero(&LGlobalConf, sizeof(LGlobalConf));
+  if ((Lenv=g_getenv("XDG_CONFIG_HOME"))) {
+    Lpath = g_strdup_printf("%s/%s/%s.conf", Lenv, PACKAGE, PACKAGE);
+    Lnewlist = g_slist_append(Lnewlist, Lpath);
+  }
 
-  g_snprintf(LUserConf, sizeof(LUserConf)-1, "%s/.%s/%s.conf", LHome, PACKAGE, PACKAGE);
-  g_snprintf(LGlobalConf, sizeof(LGlobalConf)-1, "%s/%s/%s.conf", PACKAGE_DATA_DIR, PACKAGE, PACKAGE);
+  if ((Lenv=g_getenv("HOME"))) {
+    Lpath = g_strdup_printf("%s/.config/%s/%s.conf", Lenv, PACKAGE, PACKAGE);
+    Lnewlist = g_slist_append(Lnewlist, Lpath);
+  }
 
-  if (*LUserConf && access(LUserConf, F_OK + R_OK + W_OK)==0) {
-    strcpy(Gfileconf, LUserConf);
-  } else if (*LGlobalConf && access(LGlobalConf, F_OK + R_OK + W_OK)==0) {
-    strcpy(Gfileconf, LGlobalConf);
+  if ((Lenv = g_getenv("XDG_CONFIG_DIRS"))) {
+    Llistpath = g_strsplit(Lenv, ":", 0);
+
+    for (i=0; Llistpath[i]; i++) {
+      Lpath = g_strdup_printf("%s/%s/%s.conf", Llistpath[i], PACKAGE, PACKAGE);
+      Lnewlist = g_slist_append(Lnewlist, Lpath);
+
+      g_free(Lpath);
+    }
+
+    g_strfreev(Llistpath);
+  }
+
+  return Lnewlist;
+}
+
+gboolean get_config_file(gint Lmode)
+{
+  GSList *Llistconfig = get_config_path();
+  GSList *Lcurlist;
+  gboolean Ltrouve = FALSE;
+  gchar Lonlyname[1024];
+  gchar *s;
+  
+  *Gfileconf = 0; 
+  for (Lcurlist = Llistconfig; Lcurlist; Lcurlist = g_slist_next(Lcurlist)) {
+    if (W_OK == Lmode) {
+      g_strlcpy(Lonlyname, (gchar *)Lcurlist->data, sizeof(Lonlyname)-1);      
+      if (!(s=strrchr(Lonlyname, '/'))) continue;
+      *s=0;
+      if (FALSE == sc_mkdir(Lonlyname, 00750)) continue;
+
+      Ltrouve = TRUE;
+    } else if (access((gchar *)Lcurlist->data, F_OK)==0) {
+      Ltrouve = TRUE;
+    }
+    if (Ltrouve) {
+      g_strlcpy(Gfileconf, (gchar *) Lcurlist->data, sizeof(Gfileconf)-1);
+      break;
+    }
   }
 
 #ifdef DEBUG
@@ -230,53 +274,12 @@ gint is_config_valide()
   }
 #endif
 
-  return (*Gfileconf);
-}
+  if (!Ltrouve)
+    g_strlcpy(Gfileconf, (gchar *) g_slist_nth_data(Llistconfig, 0), sizeof(Gfileconf)-1);
 
-/* on cherche un programme dans le PATH */
-gchar *trouveUnProg(gchar *Anomprog)
-{
-  struct stat Lficinfo;
-  gchar Ltest[2048], *Lpath, *s, *p;
-  gchar *Lrespath = NULL;
+  g_slist_free(Llistconfig);
 
-  Lpath = g_strdup(g_getenv("PATH"));
-
-  p = Lpath;
-  while (((s = strchr(p, ':'))) || p) {
-    if (s) *(s++)=0;
-
-    g_snprintf(Ltest, sizeof(Ltest)-1, "%s/%s", p, Anomprog);
-
-    if (0==stat(Ltest, &Lficinfo) && S_ISREG(Lficinfo.st_mode)) {
-      Lrespath = strdup(Ltest);
-      break;
-    } 
-    if (!s) break;
-    p=s;
-  }
-
-  g_free(Lpath);
-
-#ifdef DEBUG
-  if (Lrespath) {
-    _DEB("on a trouve [%s]\n", Lrespath);
-  }
-#endif
-
-  return Lrespath;
-}
-
-/* le repertoire est-il valide ? sinon renvoi celui par defaut */
-gchar *trouveUnPath(gchar *Anompath, gchar *Adefaultpath)
-{
-  struct stat Lficinfo;
-
-  if (0==stat(Anompath, &Lficinfo) && S_ISDIR(Lficinfo.st_mode)) {
-    return strdup(Anompath);
-  }
-
-  return strdup(Adefaultpath);
+  return Ltrouve;
 }
 
 /* sauve une cle dans le hash de configuration */
@@ -377,7 +380,7 @@ void manage_saveonexit_value(GHashTable *Ahash)
 }
 
 /* gestion de la configuration (creation/chargement/sauvegarde...) */
-gint manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror)
+gboolean manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror)
 {
   TProgRequis *Lcurprog;
   gchar *Lprog;
@@ -393,7 +396,7 @@ gint manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror)
     /* on recherche les programmes externes */
     for (Lcurprog = Glisteprogrequis; Lcurprog->entry; Lcurprog++) {
       if (Lcurprog->type == CONF_PROG) {
-        Lprog = trouveUnProg(Lcurprog->entry);
+        Lprog = g_find_program_in_path(Lcurprog->entry);
       } else {
         Lprog = g_strdup(Lcurprog->defaultvalue);
       }
@@ -403,6 +406,15 @@ gint manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror)
       if (! Lprog) g_warning("ERREUR LE PROG [%s] EST INDISPENSABLE ET NON TROUVE !\n", Lcurprog->entry);
 #endif
     }
+    
+    /* pour mkisofs on regarde qu'il y ai bien le support iso version 2 */
+    conf_store_value("mkisofs_support_isov2", _BOOLEAN_CONF(check_mkisofs()));
+
+    /* pour sox on regarde si il a bien le support ogg / mp3 */
+    check_sox();
+    conf_store_value("sox_support_mp3", _BOOLEAN_CONF(GsupportMp3));
+    conf_store_value("sox_support_ogg", _BOOLEAN_CONF(GsupportOgg));
+   
   }
 
   if (Aop & SEARCH_LECTEUR) {
@@ -421,14 +433,11 @@ gint manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror)
     conf_store_int("height", Lheight);
   }
 
-  if (Aop & WRITE_CONFIG) {
-    gchar *Lconffile = get_config_file_name();
-    gint Lwrstat = write_conf(Lconffile, Aerror);
-    g_free(Lconffile);
-    return Lwrstat;
+  if (Aop & WRITE_CONFIG) {    
+    return write_conf(Aerror);
   }
 
-  return 1;
+  return TRUE;
 }
 
 /* renvoi une valeur du fichier de configuration */
@@ -586,6 +595,11 @@ gboolean read_config(GError **Aerror)
   g_strfreev(Llignes);
   g_free(Lcontents);
   clean_config();
+
+  GsupportMp3 = conf_get_boolean("sox_support_mp3");
+  GsupportOgg = conf_get_boolean("sox_support_ogg");
+
+  if (!test_version()) return FALSE;  
   
   return TRUE;
 }
@@ -687,6 +701,21 @@ void save_last_dir(GtkFileChooser *Awidget)
   if (Llastdir) conf_store_value("lastdir", Llastdir);
 }
 
+/* test sur la version du fichier de configuration .. */
+gboolean test_version()
+{
+  if (!conf_get_string("confversion")) {
+    gchar *Lerrmsg = g_strdup_printf(_("graveman update !\n\nYou must remove your old configuration file '%s'.\nThen you can restart graveman..\n\nThanks ! :-)"), Gfileconf);
+    GtkWidget *Lerr = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING,
+                          GTK_BUTTONS_OK, Lerrmsg);
+    gtk_dialog_run(GTK_DIALOG(Lerr));
+    gtk_widget_destroy(Lerr);
+   
+    return FALSE;
+  }
+
+  return TRUE;
+}
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
