@@ -1165,6 +1165,19 @@ void about_graveman (void)
   g_free(Lxml);
 }
 
+void hide_some_progressbar(GHashTable *Ahash)
+{
+  GtkWidget *Lpbfifo = g_hash_table_lookup(Ahash, "pb_fifo");
+  GtkWidget *Lpbbuffer = g_hash_table_lookup(Ahash, "pb_buffer");
+  GtkWidget *Llfifo = g_hash_table_lookup(Ahash, "l_fifo");
+  GtkWidget *Llbuffer = g_hash_table_lookup(Ahash, "l_buffer");
+
+  gtk_widget_hide(Lpbfifo); 
+  gtk_widget_hide(Llfifo); 
+  gtk_widget_hide(Lpbbuffer); 
+  gtk_widget_hide(Llbuffer); 
+}
+
 /* fenetre gravure d'un cd en cours */
 void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
 {
@@ -1200,6 +1213,7 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
   g_hash_table_insert(Ahash, "progress", Lpbstep);
   Lpbfifo = GTK_PROGRESS_BAR(glade_to_hash(Lxml, Ahash, "pb_fifo"));
   Lpbbuffer = GTK_PROGRESS_BAR(glade_to_hash(Lxml, Ahash, "pb_buffer"));
+  glade_to_hash_list(Lxml, Ahash, "l_fifo", "l_buffer", NULL);
 
   /* on attache les variables utilisees lors de l'operation */
   g_hash_table_insert(Ahash, "totaldone", &Ltotaldone);
@@ -1222,6 +1236,7 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
   } else if (g_str_has_prefix(Aaction, "btnburndata")) {
     Lbackvalue = burn_data(Ahash, &Lerror);
   } else if (g_str_has_prefix(Aaction, "btnburndvddata")) {
+    hide_some_progressbar(Ahash);
     Lbackvalue = burn_dvddata(Ahash, &Lerror);
   }
 
