@@ -213,7 +213,7 @@ _DEB("debut !!");
   while (*Lcont > 0 && *Labort == FALSE) {
    gtk_main_iteration();
   }
-  exit_prog(*Lpid, Aerror, NULL);
+  exit_prog(*Lpid, *Labort, Aerror, NULL);
 
 _DEB("fin !!");
 
