@@ -1,5 +1,5 @@
 /* tools.c
- * Copyright (C) 2004, 2005 Sylvain Cresto <sylvain.cresto@tiscali.fr>
+ * Copyright (C) 2004, 2005 Sylvain Cresto <scresto@gmail.com>
  *
  * This file is part of graveman!
  *
@@ -121,7 +121,7 @@ gshort make_short(gchar *Abuf)
 }
 
 /* format un nombre en chaine de la forme MM:SS */
-gchar *format_length(guint32 Alennbr)
+gchar *format_length(guint64 Alennbr)
 {
    guint Lmin = 0, Lsec = 0;
 
@@ -132,26 +132,26 @@ gchar *format_length(guint32 Alennbr)
 }
 
 /* format un nombre en taille de la forme XX Mo ou XX Ko oo XX octets */
-gchar *format_size(guint32 Asize)
+gchar *format_size(guint64 Asize)
 {
-  guint32 Lko = Asize / 1024;
+  guint64 Lko = Asize / 1024;
   gdouble Lreste;
-  guint32 Lmo;
+  guint64 Lmo;
 
-  if (Lko < 1) return g_strdup_printf("%d %s", Asize, Asize > 1 ? _("octets") : _("octet"));
+  if (Lko < 1) return g_strdup_printf("%lld %s", (unsigned long long) Asize, Asize > 1 ? _("octets") : _("MB"));
   Lmo = Lko / 1024;
 
   if (Lmo < 1) {
     if (Asize - (Lko * 1024) > 511) Lko++;
-    return g_strdup_printf(_("%d K"), Lko);
+    return g_strdup_printf(_("%lld K"), (unsigned long long) Lko);
   }
 
   Lreste = (Lko - (Lmo * 1024));
   Lreste = Lreste / 1024;
   if (Lreste > 0 && Lreste < 1) {
-    return g_strdup_printf(_("%d.%.0f MB"), Lmo, Lreste * 10);
+    return g_strdup_printf(_("%lld.%.0f MB"), (unsigned long long) Lmo, Lreste * 10);
   } else {
-    return g_strdup_printf(_("%d MB"), Lmo);
+    return g_strdup_printf(_("%lld MB"), (unsigned long long) Lmo);
   }
 }
 
@@ -316,6 +316,57 @@ gchar * sc_strescape (const gchar *source)
   return dest;
 }
 
+/* fin d'un programme externe, on defini une erreur si il ne s'est pas termin correctement */
+void exit_prog(gint Apid, gboolean Aabort, GError **Aerror, gchar *Adefmsg)
+{
+  gint Lcmdstatus = 0;
+
+  if (Aabort) kill(Apid, SIGTERM);
+  waitpid(Apid, &Lcmdstatus, 0);
+  if ((WIFEXITED(Lcmdstatus) && WEXITSTATUS(Lcmdstatus)!=0) || (!(WIFEXITED(Lcmdstatus)))) {
+    _DEB("oui une erreur\n");
+    if (Aerror && !*Aerror) {
+      g_set_error(Aerror, GRAVEMAN_ERROR, _ERR_UNKNOWN_ERROR, Adefmsg ? Adefmsg : _("Operation failed"));
+    }
+  }
+}
+
+/* creation de tous les repertoires necessaires */
+gint sc_mkdir(const gchar *Aname, mode_t Amode) {
+  gchar **Llist = g_strsplit(Aname, G_DIR_SEPARATOR_S, 0);
+  gchar *Ldir = NULL, *Ltmp = NULL;
+  gint Lstatus = TRUE;
+  gint i;
+
+  for (i=0; Llist[i]; i++) {
+    if (!*Llist[i]) continue;
+
+    if (Ldir) {
+      Ltmp = g_strconcat(Ldir, "/", Llist[i], NULL);
+      g_free(Ldir);
+    } else {
+      Ltmp = g_strconcat("/", Llist[i], NULL);
+    }
+    Ldir = Ltmp;
+  
+    if (g_file_test(Ldir, G_FILE_TEST_IS_DIR)) continue;
+
+    if (g_file_test(Ldir, G_FILE_TEST_EXISTS)) {
+      Lstatus = FALSE;
+      break;
+    }
+
+    if (mkdir(Ldir, Amode)!=0) {
+      Lstatus = FALSE;
+      break;
+    }
+  }
+  
+  g_free(Ldir);
+  g_strfreev(Llist);
+
+  return Lstatus;
+}
 
 /*
  * vim:et:ts=8:sts=2:sw=2
